import {
  DB,
  DBConnectorModel,
  DBConnectorFilterQuery,
  DBConnectorDocument
} from '@yeeti/modules-db';

/**
 * Interface - DB Model
 */
interface DBModelInterface {
  /**
   * Database
   */
  db: DB;

  /**
   * Model
   */
  client: DBConnectorModel;

  /**
   * Model name (defaulted to contructor.name)
   */
  name(): String;
  /**
   * Dictionary of Model properties
   */
  properties(): { [key: string]: any };
  /**
   * List of indexes
   */
  indexes(): Array<{ [key: string]: 1 | -1 }>;

  /**
   * Count how many documents in Model with conditions
   * @param conditions model properties to filter
   */
  count(conditions: DBConnectorFilterQuery): Promise<number>;
  /**
   * Check if a document exists with conditions
   * @param conditions model properties to filter
   */
  exists(conditions: DBConnectorFilterQuery): Promise<boolean>;
  /**
   * Create a new document with data
   * @param data data to create document
   */
  create(data: any): Promise<DBConnectorDocument>;
}
