"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class DBModel {
    /**
     * Initialize DB Model
     * @param db Databse Instance
     */
    constructor(db) {
        this.db = db;
        this.client = this.attachToDB();
    }
    /**
     * Model name (defaulted to contructor.name)
     */
    name() {
        return this.constructor.name;
    }
    /**
     * Dictionary of Model properties
     */
    properties() {
        return {};
    }
    /**
     * List of indexes
     */
    indexes() {
        return [];
    }
    /**
     * Attach current model to DB instance
     */
    attachToDB() {
        const { db, client } = this;
        if (client) {
            throw new Error('Already attached to DB');
        }
        const name = this.name();
        const properties = this.properties();
        const indexes = this.indexes();
        return db.attachModel(name, properties, indexes);
    }
    /**
     * Count how many documents in Model with conditions
     * @param conditions model properties to filter
     */
    async count(conditions) {
        const { client } = this;
        const count = await client.count(conditions);
        return count;
    }
    /**
     * Check if a document exists with conditions
     * @param conditions model properties to filter
     */
    async exists(conditions) {
        const { client } = this;
        const exists = await client.exists(conditions);
        return exists;
    }
    /**
     * Create a new document with data
     * @param data data to create document
     */
    async create(data) {
        const { client } = this;
        const document = await client.create(data);
        return document;
    }
}
exports.DBModel = DBModel;
//# sourceMappingURL=db-model.js.map